Index: trunk/info/info/alkisn/alkisfshist.php
===================================================================
--- trunk/info/info/alkisn/alkisfshist.php	(revision 425)
+++ trunk/info/info/alkisn/alkisfshist.php	(revision 427)
@@ -1,7 +1,10 @@
 <?php
-/*	Modul: alkisfshist.php
-
-	ALKIS-Buchauskunft, Kommunales Rechenzentrum Minden-Ravensberg/Lippe (Lemgo).
-	Flurstuecks-Historie fuer ein Flurstueckskennzeichen aus ALKIS PostNAS
+/*	alkisfshist.php
+
+	ALKIS-Auskunft
+	Author: Frank JÃ€ger, Kommunales Rechenzentrum Minden-Ravensberg/Lippe (Lemgo)
+
+	FlurstÃŒcks-Historie fÃŒr ein FlurstÃŒckskennzeichen aus ALKIS PostNAS
+
 	Version:
 	2016-02-24 Version fÃŒr norGIS-ALKIS-Import
@@ -11,8 +14,9 @@
 	2020-12-15 Input-Validation und Strict Comparisation (===)
 	2021-12-09 Neuer Parameter $PrntBtn (Drucken-SchaltflÃ€che)
+	2022-01-13 Neue Functions LnkStf(), DsKy()
 */
 
 function fzerleg($fs) {
 /*	Flurstueckskennzeichen (20) zerlegen als lesbares Format (wie im Balken):
 	Dies FS-Kennz-Format wird auch als Eingabe in der Navigation akzeptiert 
    ....*....1....*....2
@@ -37,7 +41,5 @@
 		$arr = explode(",",$stri);
 		foreach($arr AS $val){
-			echo "Flurst&uuml;ck <a title=' zur Flurst&uuml;ck Historie' href='".selbstverlinkung()."?gkz=".$gkz."&amp;fskennz=".$val;
-			if ($showkey)   {echo "&amp;showkey=j";}
-			echo "'>".fzerleg($val)."</a><br>";
+			echo "Flurst&uuml;ck <a title=' zur Flurst&uuml;ck Historie' href='".selbstverlinkung()."?gkz=".$gkz."&amp;fskennz=".$val.LnkStf()."'>".fzerleg($val)."</a><br>";
 		}
 	}
@@ -90,7 +92,5 @@
 		$gmlv=$rowv["gml_id"];
 		$vfsk=$rowv["flurstueckskennzeichen"];
-		echo "Flurst&uuml;ck <a title='Historie des Vorg&auml;ngerflurst&uuml;cks' href='".selbstverlinkung()."?gkz=".$gkz."&amp;fskennz=".$vfsk."&amp;gmlid=".$gmlv;
-			if ($showkey) {echo "&amp;showkey=j";}
-		echo "'>".fzerleg($vfsk)."</a><br>";
+		echo "Flurst&uuml;ck <a title='Historie des Vorg&auml;ngerflurst&uuml;cks' href='".selbstverlinkung()."?gkz=".$gkz."&amp;fskennz=".$vfsk."&amp;gmlid=".$gmlv.LnkStf()."'>".fzerleg($vfsk)."</a><br>";
 		$zv++;
 	}
@@ -102,5 +102,4 @@
 
 // Start
-
 ini_set("session.cookie_httponly", 1);
 session_start();
@@ -147,8 +146,5 @@
 
 $erlaubnis = darf_ich(); if ($erlaubnis === 0) { die('<p class="stop1">Abbruch</p></body>'); }
-$dbg=$debug; // CONF in Arbeits-Variable
-
-// Mit URL-Parameter "&nodebug=j" kann man die Entwicklungsumgebung (in Conf definiert) ausschalten.
-// Wirkt temporÃ€r und wird nicht in Links weiter gereicht.
+$dbg=$debug;
 if ($nodebug === "j") {$dbg=0;} 
 
@@ -251,7 +247,5 @@
 	."\n\t<table class='".$cls."' title='Flurst&uuml;ckskennzeichen'>\n\t<tr>" // innere Tabelle Kennzeichen
 		."\n\t\t<td class='head'>Gemarkung</td>\n\t\t<td class='head'>Flur</td>\n\t\t<td class='head'>Flurst-Nr.</td>\n\t</tr>"
-		."\n\t<tr>\n\t\t<td title='Gemarkung'>";
-		if ($showkey) {echo "<span class='key'>".$gmkgnr."</span><br>";}
-		echo $gemkname."&nbsp;</td>"
+		."\n\t<tr>\n\t\t<td title='Gemarkung'>".DsKy($gmkgnr, 'Gemarkungsnummer').$gemkname."&nbsp;</td>"
 		."\n\t\t<td title='Flurnummer'>".$flurnummer."</td>"
 		."\n\t\t<td title='Flurst&uuml;cksnummer (Z&auml;hler / Nenner)'><span class='wichtig'>".$flstnummer."</span></td>\n\t</tr>"
@@ -263,9 +257,6 @@
 if ($ftyp === "a") { // Aktuell -> Historie
 	echo "\n<p class='nwlink noprint'>weitere Auskunft: "
-		."<a href='alkisfsnw.php?gkz=".$gkz."&amp;gmlid=".$gmlid."&amp;eig=n";
-			if ($showkey)   {echo "&amp;showkey=j";}
-			echo "' title='Flurst&uuml;cksnachweis'>Flurst&uuml;ck "
-			."<img src='ico/Flurstueck_Link.png' width='16' height='16' alt=''>"
-		."</a>";
+	."<a href='alkisfsnw.php?gkz=".$gkz."&amp;gmlid=".$gmlid.LnkStf()."&amp;eig=n' title='Flurst&uuml;cksnachweis'>Flurst&uuml;ck "
+	."<img src='ico/Flurstueck_Link.png' width='16' height='16' alt=''></a>";
 }
 echo "\n<hr>"
@@ -277,5 +268,5 @@
 	</tr>"; // Head
 	
-	// Spalte 1: F l u r s t ÃŒ c k
+	// Sp.1: FlurstÃŒck
 	echo "\n<tr>\n\t<td>"
 		."<img src='ico/".$ico."' width='16' height='16' alt=''> ".$wert
@@ -283,5 +274,5 @@
 	."</td>";
 
-	// Spalte 2: V o r g Ã€ n g e r
+	// Sp.2: VorgÃ€nger
 	echo "\n\t<td>";
 	switch ($ftyp) { // Diff. Hist./Akt.
@@ -298,5 +289,5 @@
 	echo"</td>";
 
-	// Spalte 3: N a c h f o l g e r
+	// Sp.3: Nachfolger
 	echo "\n\t<td>";
 		vornach($nach);
@@ -11,8 +14,9 @@
 
 function fzerleg($fs) {
-/*	Flurstueckskennzeichen (20) zerlegen als lesbares Format (wie im Balken):
+/*	FlurstÃŒckskennzeichen (20) zerlegen als lesbares Format (wie im Balken):
 	Dies FS-Kennz-Format wird auch als Eingabe in der Navigation akzeptiert 
    ....*....1....*....2
